Profile Extraction
==================

Functions for extracting interaction profiles from molecules.

extract_profiles
----------------

.. automodule:: shepherd_score.extract_profiles
   :members:
   :undoc-members:
   :show-inheritance:

generate_point_cloud
--------------------

.. automodule:: shepherd_score.generate_point_cloud
   :members:
   :undoc-members:
   :show-inheritance:
